/************************************************************************
 *   IRC - Internet Relay Chat, src/motd.c
 *   Copyright (C) 1990 Jarkko Oikarinen and
 *                      University of Oulu, Computing Center
 *
 *   See file AUTHORS in IRC package for additional names of
 *   the programmers. 
 *
 *   This program is free software; you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation; either version 1, or (at your option)
 *   any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 *   $Id: m_motd.c,v 1.1 2001/09/16 22:48:04 asuffield Exp $
 */
#include "motd.h"
#include "ircd.h"
#include "s_bsd.h"
#include "fileio.h"
#include "res.h"
#include "s_conf.h"
#include "class.h"
#include "send.h"
#include "s_conf.h"
#include "numeric.h"
#include "client.h"
#include "irc_string.h"
#include "s_serv.h"		/* hunt_server */
#include "umodes.h"
#include "memory.h"
#include "msg.h"
#include "handlers.h"

#include <string.h>
#include <stdlib.h>
#include <time.h>

int m_motd(struct Client *, struct Client *, int, char **);

struct Message motd_msgtab = {
  "MOTD", 0, 0, 1, MFLG_SLOW, 0,
  {m_unregistered, m_motd, m_motd},
  NULL, NULL
};

extern ConfigFileEntryType ConfigFileEntry;	/* defined in ircd.c */

/*
** m_motd
**      parv[0] = sender prefix
**      parv[1] = servername
*/
int
m_motd(struct Client *cptr, struct Client *sptr, int parc, char *parv[])
{
  static time_t last_used = 0;

  /* uhh.. servers should not send a motd request.. */
  if (IsServer(sptr))
    return 0;

  if (!NoFloodProtection(sptr))
    {
      if ((last_used + PACE_WAIT) > CurrentTime)
	{
	  /* safe enough to give this on a local connect only */
	  if (MyClient(sptr))
	    sendto_one(sptr, form_str(RPL_LOAD2HI), me.name, sptr->name);
	  return 0;
	}
      else
	last_used = CurrentTime;
    }

  if (MyClient(sptr) && !HasUmode(sptr, UMODE_REMOTEINFO) && parc > 1)
    {
      if (SeesOperMessages(sptr))
	sendto_one(sptr, get_str(STR_NEEDPRIV), me.name, parv[0],
		   user_mode_char[UMODE_REMOTEINFO]);
      else
	sendto_one(sptr, form_str(ERR_NOPRIVILEGES), me.name, parv[0]);
      return 0;
    }

  if (hunt_server(cptr, sptr, ":%s MOTD :%s", 1, parc, parv) != HUNTED_ISME)
    return 0;

  sendto_ops_flag(UMODE_SPY, "motd requested by %s (%s@%s) [%s]",
		  sptr->name, sptr->username, sptr->host, sptr->user->server);

  return (SendMessageFile(sptr, &ConfigFileEntry.motd));
}
